@@ -3,22 +3,19 @@
 #' Generate `shortanswer` question
 #'
 #' @param answer A string.
+#' @param fb_answer A string, answer feedback.
 #'
 #' @return A string.
 #' @keywords internal
-generate_shortanswer <- function(answer) {
+generate_shortanswer <- function(answer, fb_answer) {
   question_body <- glue::glue(
     '
 
-    <defaultgrade>1.0000000</defaultgrade>
-    <penalty>0.3333333</penalty>
-    <hidden>0</hidden>
-    <idnumber></idnumber>
     <usecase>0</usecase>
     <answer fraction="100" format="moodle_auto_format">
       <text>{answer}</text>
       <feedback format="html">
-        <text></text>
+        <text>{fb_answer}</text>
       </feedback>
     </answer>
 '
